<?php

namespace Drupal\synhelper\Service;

/**
 * ParagraphImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class ParagraphImport implements ContentImportInterface {
  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\TaxonomyImport
   */

  protected $taxonomyImport;

  /**
   * Controller constructor.
   */
  public function __construct(ContentImportInterface $filesImport, ContentImportInterface $taxonomyImport) {
    $this->filesImport = $filesImport;
    $this->taxonomyImport = $taxonomyImport;
  }

  /**
   * Import Paragraph(about && image_blocks && Параметры).
   *
   * If needed more just copy one of them and set your fields.
   */
  public function import($field_paragraph) : array {
    $storage = \Drupal::service('entity_type.manager')->getStorage('paragraph');
    $paragraphs = [];

    /* Importing About Us */
    if (!empty($field_paragraph['about'])) {
      $items = [];
      $about = $field_paragraph['about'];
      foreach ($about['field_about_items'] as $about_item) {
        $about_item['field_image'] = $this->filesImport->importImages($about_item['field_image']);
        $item = $storage->create($about_item);
        $item->save();
        $items[] = [
          'uid' => 1,
          'type' => $about_item['type'],
          'target_id' => $item->id(),
          'target_revision_id' => $item->getRevisionId(),
          'field_about_icon' => $about_item['field_about_icon'],
          'field_title' => $about_item['field_title'],
          'field_description' => $about_item['field_description'],
        ];
      }
      $about['field_about_items'] = $items;
      $paragraph = $storage->create($about);
      $paragraph->save();
      $paragraphs[] = [
        'type' => $about['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Image Blocks */
    if (!empty($field_paragraph['image_blocks'])) {
      $items = [];
      $imageBloсks = $field_paragraph['image_blocks'];
      foreach ($imageBloсks['field_image_blocks_items'] as $image_blocks_item) {
        $image_blocks_item['field_image'] = $this->filesImport->importImages($image_blocks_item['field_image']);
        $item = $storage->create($image_blocks_item);
        $item->save();
        $items[] = [
          'uid' => 1,
          'type' => $image_blocks_item['type'],
          'target_id' => $item->id(),
          'target_revision_id' => $item->getRevisionId(),
          'field_title' => $image_blocks_item['field_title'],
          'field_body' => $image_blocks_item['field_body'],
          'field_image_text_sort' => $image_blocks_item['field_image_text_sort'],
        ];
      }
      $imageBloсks['field_image_blocks_items'] = $items;
      $paragraph = $storage->create($imageBloсks);
      $paragraph->save();

      $paragraphs[] = [
        'type' => $imageBloсks['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Описание */
    if (!empty($field_paragraph['body'])) {
      $body = $field_paragraph['body'];
      $p = [
        'uid' => 1,
        'type' => $body['type'],
        'field_title' => $body['field_title'],
        'field_body' => $body['field_body'],
      ];
      $paragraph = $storage->create($p);
      $paragraph->save();
      $paragraphs[] = [
        'type' => $body['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Изображение */
    if (!empty($field_paragraph['image_text'])) {
      $image_text = $field_paragraph['image_text'];
      $p = [
        'uid' => 1,
        'type' => $image_text['type'],
        'field_title' => $image_text['field_title'],
        'field_image' => $this->filesImport->importImages($image_text['field_image']),
        'field_body' => $image_text['field_body'],
      ];
      $paragraph = $storage->create($p);
      $paragraph->save();
      $paragraphs[] = [
        'type' => $image_text['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Текс+изображение на плашке */
    if (!empty($field_paragraph['text_image_plate'])) {
      $text_image_plate = $field_paragraph['text_image_plate'];
      $p = [
        'uid' => 1,
        'type' => $text_image_plate['type'],
        'field_title' => $text_image_plate['field_title'],
        'field_image' => $this->filesImport->importImages($text_image_plate['field_image']),
        'field_body' => $text_image_plate['field_body'],
      ];
      $paragraph = $storage->create($p);
      $paragraph->save();
      $paragraphs[] = [
        'type' => $text_image_plate['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Состав работ */
    if (!empty($field_paragraph['work_scope'])) {
      $items = [];
      $work_scope = $field_paragraph['work_scope'];
      foreach ($work_scope['field_work_scope_items'] as $work_scope_item) {
        $item = $storage->create($work_scope_item);
        $item->save();
        $items[] = [
          'uid' => 1,
          'type' => $work_scope_item['type'],
          'target_id' => $item->id(),
          'target_revision_id' => $item->getRevisionId(),
          'field_title' => $work_scope_item['field_title'],
          'field_short' => $work_scope_item['field_short'],
        ];
      }
      $work_scope['field_work_scope_items'] = $items;
      $paragraph = $storage->create($work_scope);
      $paragraph->save();
      $paragraphs[] = [
        'type' => $work_scope['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Gallery */
    if (!empty($field_paragraph['gallery'])) {
      $items = [];
      $gallery = $field_paragraph['gallery'];
      foreach ($gallery['field_gallery_image_text'] as $image_text) {
        $image_text['field_image'] = $this->filesImport->importImages($image_text['field_image']);
        $item = $storage->create($image_text);
        $item->save();
        $items[] = [
          'uid' => 1,
          'type' => $image_text['type'],
          'target_id' => $item->id(),
          'target_revision_id' => $item->getRevisionId(),
          'field_title' => $image_text['field_title'],
          'field_body' => $image_text['field_body'],
        ];
      }
      $gallery['field_gallery_image_text'] = $items;
      $paragraph = $storage->create($gallery);
      $paragraph->save();
      $paragraphs[] = [
        'type' => $gallery['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Параметры */
    if (!empty($field_paragraph['product_param'])) {
      foreach ($field_paragraph['product_param'] as $param) {
        $t = [
          'uid' => 1,
          'type' => $param['type'],
          'field_product_param_param' => $param['field_product_param_param'],
          'field_product_param_value' => $param['field_product_param_value'],
        ];
        $paragraph = $storage->create($t);
        $paragraph->save();
        $paragraphs[] = [
          'type' => 'product_param',
          'target_id' => $paragraph->id(),
          'target_revision_id' => $paragraph->getRevisionId(),
        ];
      }
    }

    /* Importing Галерея работ */
    if (!empty($field_paragraph['gallery_work'])) {
      $gallery_work = $field_paragraph['gallery_work'];
      $p = [
        'uid' => 1,
        'type' => $gallery_work['type'],
        'field_title' => $gallery_work['field_title'],
        'field_gallery' => $this->filesImport->importImages($gallery_work['field_gallery']),
        'field_body' => $gallery_work['field_body'],
      ];
      $paragraph = $storage->create($p);
      $paragraph->save();
      $paragraphs[] = [
        'type' => $gallery_work['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Слайдер с текстом */
    if (!empty($field_paragraph['text_slider'])) {
      $text_slider = $field_paragraph['text_slider'];
      $p = [
        'uid' => 1,
        'type' => $text_slider['type'],
        'field_title' => $text_slider['field_title'],
        'field_gallery' => $this->filesImport->importImages($text_slider['field_gallery']),
        'field_body' => $text_slider['field_body'],
      ];
      $paragraph = $storage->create($p);
      $paragraph->save();
      $paragraphs[] = [
        'type' => $text_slider['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }
    return $paragraphs;
  }

}
